from flask import Flask
from flask_login import LoginManager
from sqlalchemy import create_engine
from sqlalchemy.orm import sessionmaker

from .config import ContactSettings
from .models import User

# Database
engine = create_engine(ContactSettings().DATABASE_URI)
Session = sessionmaker(engine)

# Configure Authentication
login_manager = LoginManager()
login_manager.session_protection = "strong"
login_manager.login_view = "user.user_login"


@login_manager.user_loader
def load_user(userid):
    with Session() as session:
        return session.get(User, userid)


def create_app(config: ContactSettings = None):
    app = Flask("htmx_contact")

    app.config.from_object(config if config else ContactSettings())
    login_manager.init_app(app)

    from . import main

    app.register_blueprint(main.bp)

    from . import user

    app.register_blueprint(user.bp)

    return app
